summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMark Brown <broonie@kernel.org>2021-02-08 15:01:44 +0000
committerMark Brown <broonie@kernel.org>2021-02-08 15:01:44 +0000
commit3bf48ea4f2dd404d4bfe4e4ded136df7843c21b0 (patch)
treefb9519398e47f237a87de45823dec698a0796dc1
parent40bd053bc8e18b68e877bd4cdea1b6938ddf5fdd (diff)
parent0d7475d2a5a90127a2f87961b99bcd8f95694dd9 (diff)
Merge series "Rename audio graph export functions" from Sameer Pujar <spujar@nvidia.com>:
This series renames exported functions from audio graph for a better global visibility. In doing so update the references in audio graph and Tegra audio graph card drivers. Changelog ========= v2 -> v3: --------- [Patch v3 1/2]: - Squashed "patch v2 1/3" and "patch v2 2/3". Updated commit message accordingly. - Add "Acked-by" tag from Morimoto-san. [Patch v3 2/2]: - Add "Acked-by" tag from Morimoto-san. v1 -> v2: --------- [Patch v2 1/3]: - Rename graph_parse_of() to audio_graph_parse_of() and graph_card_probe() to audio_graph_card_probe() as well. - Update above references in audio graph driver. [Patch v2 2/3]: New patch - Update references for audio_graph_parse_of() and audio_graph_card_probe() in Tegra graph driver. - Add "Depends-on" tag [Patch v2 3/3]: - Update commit message to add "Depends-on" tag. Sameer Pujar (2): ASoC: audio-graph: Rename functions needed for export ASoC: tegra: Add driver remove() callback include/sound/graph_card.h | 6 ++++-- sound/soc/generic/audio-graph-card.c | 17 +++++++++-------- sound/soc/tegra/tegra_audio_graph_card.c | 9 +++++---- 3 files changed, 18 insertions(+), 14 deletions(-) -- 2.7.4
-rw-r--r--include/sound/graph_card.h6
-rw-r--r--sound/soc/generic/audio-graph-card.c17
-rw-r--r--sound/soc/tegra/tegra_audio_graph_card.c9
3 files changed, 18 insertions, 14 deletions
diff --git a/include/sound/graph_card.h b/include/sound/graph_card.h
index bbb5a137855c..013784467bec 100644
--- a/include/sound/graph_card.h
+++ b/include/sound/graph_card.h
@@ -9,8 +9,10 @@
#include <sound/simple_card_utils.h>
-int graph_card_probe(struct snd_soc_card *card);
+int audio_graph_card_probe(struct snd_soc_card *card);
-int graph_parse_of(struct asoc_simple_priv *priv, struct device *dev);
+int audio_graph_parse_of(struct asoc_simple_priv *priv, struct device *dev);
+
+int audio_graph_remove(struct platform_device *pdev);
#endif /* __GRAPH_CARD_H */
diff --git a/sound/soc/generic/audio-graph-card.c b/sound/soc/generic/audio-graph-card.c
index 16a04a678828..8c5cdcdc8713 100644
--- a/sound/soc/generic/audio-graph-card.c
+++ b/sound/soc/generic/audio-graph-card.c
@@ -532,7 +532,7 @@ static int graph_for_each_link(struct asoc_simple_priv *priv,
static void graph_get_dais_count(struct asoc_simple_priv *priv,
struct link_info *li);
-int graph_parse_of(struct asoc_simple_priv *priv, struct device *dev)
+int audio_graph_parse_of(struct asoc_simple_priv *priv, struct device *dev)
{
struct snd_soc_card *card = simple_priv_to_card(priv);
struct link_info li;
@@ -608,7 +608,7 @@ err:
return ret;
}
-EXPORT_SYMBOL_GPL(graph_parse_of);
+EXPORT_SYMBOL_GPL(audio_graph_parse_of);
static int graph_count_noml(struct asoc_simple_priv *priv,
struct device_node *cpu_ep,
@@ -705,7 +705,7 @@ static void graph_get_dais_count(struct asoc_simple_priv *priv,
li->link, li->dais, li->conf);
}
-int graph_card_probe(struct snd_soc_card *card)
+int audio_graph_card_probe(struct snd_soc_card *card)
{
struct asoc_simple_priv *priv = snd_soc_card_get_drvdata(card);
int ret;
@@ -720,7 +720,7 @@ int graph_card_probe(struct snd_soc_card *card)
return 0;
}
-EXPORT_SYMBOL_GPL(graph_card_probe);
+EXPORT_SYMBOL_GPL(audio_graph_card_probe);
static int graph_probe(struct platform_device *pdev)
{
@@ -736,20 +736,21 @@ static int graph_probe(struct platform_device *pdev)
card = simple_priv_to_card(priv);
card->dapm_widgets = graph_dapm_widgets;
card->num_dapm_widgets = ARRAY_SIZE(graph_dapm_widgets);
- card->probe = graph_card_probe;
+ card->probe = audio_graph_card_probe;
if (of_device_get_match_data(dev))
priv->dpcm_selectable = 1;
- return graph_parse_of(priv, dev);
+ return audio_graph_parse_of(priv, dev);
}
-static int graph_remove(struct platform_device *pdev)
+int audio_graph_remove(struct platform_device *pdev)
{
struct snd_soc_card *card = platform_get_drvdata(pdev);
return asoc_simple_clean_reference(card);
}
+EXPORT_SYMBOL_GPL(audio_graph_remove);
static const struct of_device_id graph_of_match[] = {
{ .compatible = "audio-graph-card", },
@@ -766,7 +767,7 @@ static struct platform_driver graph_card = {
.of_match_table = graph_of_match,
},
.probe = graph_probe,
- .remove = graph_remove,
+ .remove = audio_graph_remove,
};
module_platform_driver(graph_card);
diff --git a/sound/soc/tegra/tegra_audio_graph_card.c b/sound/soc/tegra/tegra_audio_graph_card.c
index 9e43f16f9336..ddedf18adde1 100644
--- a/sound/soc/tegra/tegra_audio_graph_card.c
+++ b/sound/soc/tegra/tegra_audio_graph_card.c
@@ -2,7 +2,7 @@
//
// tegra_audio_graph_card.c - Audio Graph based Tegra Machine Driver
//
-// Copyright (c) 2020 NVIDIA CORPORATION. All rights reserved.
+// Copyright (c) 2020-2021 NVIDIA CORPORATION. All rights reserved.
#include <linux/math64.h>
#include <linux/module.h>
@@ -184,7 +184,7 @@ static int tegra_audio_graph_card_probe(struct snd_soc_card *card)
return PTR_ERR(priv->clk_plla_out0);
}
- return graph_card_probe(card);
+ return audio_graph_card_probe(card);
}
static int tegra_audio_graph_probe(struct platform_device *pdev)
@@ -201,12 +201,12 @@ static int tegra_audio_graph_probe(struct platform_device *pdev)
card->probe = tegra_audio_graph_card_probe;
/* graph_parse_of() depends on below */
card->component_chaining = 1;
priv->simple.ops = &tegra_audio_graph_ops;
priv->simple.force_dpcm = 1;
- return graph_parse_of(&priv->simple, dev);
+ return audio_graph_parse_of(&priv->simple, dev);
}
static const struct tegra_audio_cdata tegra210_data = {
@@ -243,6 +243,7 @@ static struct platform_driver tegra_audio_graph_card = {
.of_match_table = graph_of_tegra_match,
},
.probe = tegra_audio_graph_probe,
+ .remove = audio_graph_remove,
};
module_platform_driver(tegra_audio_graph_card);
@@ -201,12 +201,12 @@ static int tegra_audio_graph_probe(struct platform_device *pdev)
card->probe = tegra_audio_graph_card_probe;
- /* graph_parse_of() depends on below */
+ /* audio_graph_parse_of() depends on below */
card->component_chaining = 1;
priv->simple.ops = &tegra_audio_graph_ops;